@@ -18,14 +18,11 @@
  *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include <hamlib/config.h>
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <unistd.h>
 
 #include "hamlib/rig.h"
 #include "serial.h"
@@ -195,7 +192,7 @@ const struct rig_caps ar3030_caps =
     .get_channel = ar3030_get_channel,
 
     .vfo_op = ar3030_vfo_op,
-
+    .hamlib_check_rig_caps = HAMLIB_CHECK_RIG_CAPS
 };
 
 /*
@@ -236,7 +233,7 @@ static int ar3030_transaction(RIG *rig, const char *cmd, int cmd_len,
 
     do
     {
-        retval = write_block(&rs->rigport, cmd, cmd_len);
+        retval = write_block(&rs->rigport, (unsigned char *) cmd, cmd_len);
 
         if (retval != RIG_OK)
         {
@@ -247,7 +244,8 @@ static int ar3030_transaction(RIG *rig, const char *cmd, int cmd_len,
         if (data)
         {
             /* expecting 0x0d0x0a on all commands so wait for the 0x0a */
-            retval = read_string(&rs->rigport, data, BUFSZ, "\x0a", 1);
+            retval = read_string(&rs->rigport, (unsigned char *) data, BUFSZ,
+                                 "\x0a", 1, 0, 1);
 
             if (retval == -RIG_ETIMEOUT)
             {
@@ -284,7 +282,7 @@ int ar3030_init(RIG *rig)
 {
     struct ar3030_priv_data *priv;
 
-    rig->state.priv = malloc(sizeof(struct ar3030_priv_data));
+    rig->state.priv = calloc(1, sizeof(struct ar3030_priv_data));
 
     if (!rig->state.priv)
     {
@@ -376,11 +374,11 @@ int ar3030_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 {
     struct ar3030_priv_data *priv = (struct ar3030_priv_data *)rig->state.priv;
     char freqbuf[BUFSZ];
-    int freq_len, retval;
+    int retval;
 
-    freq_len = sprintf(freqbuf, "%03.6f" CR, ((double)freq) / MHz(1));
+    SNPRINTF(freqbuf, sizeof(freqbuf), "%03.6f" CR, ((double)freq) / MHz(1));
 
-    retval = ar3030_transaction(rig, freqbuf, freq_len, NULL, NULL);
+    retval = ar3030_transaction(rig, freqbuf, strlen(freqbuf), NULL, NULL);
 
     if (retval != RIG_OK)
     {
@@ -438,7 +436,7 @@ int ar3030_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 int ar3030_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 {
     char mdbuf[BUFSZ];
-    int mdbuf_len, aormode, retval;
+    int aormode, retval;
 
     switch (mode)
     {
@@ -478,16 +476,16 @@ int ar3030_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 
     if (width != RIG_PASSBAND_NOCHANGE)
     {
-        mdbuf_len = sprintf(mdbuf, "%c" CR, aormode);
+        SNPRINTF(mdbuf, sizeof(mdbuf), "%c" CR, aormode);
     }
     else
     {
-        mdbuf_len = sprintf(mdbuf, "%dB%c" CR,
-                            width < rig_passband_normal(rig, mode) ? 1 : 0,
-                            aormode);
+        SNPRINTF(mdbuf, sizeof(mdbuf), "%dB%c" CR,
+                 width < rig_passband_normal(rig, mode) ? 1 : 0,
+                 aormode);
     }
 
-    retval = ar3030_transaction(rig, mdbuf, mdbuf_len, NULL, NULL);
+    retval = ar3030_transaction(rig, mdbuf, strlen(mdbuf), NULL, NULL);
 
     return retval;
 }
@@ -566,8 +564,8 @@ int ar3030_set_mem(RIG *rig, vfo_t vfo, int ch)
     if (priv->curr_vfo == RIG_VFO_MEM)
     {
         char cmdbuf[BUFSZ];
-        int cmd_len = sprintf(cmdbuf, "%02dM" CR, ch);
-        retval = ar3030_transaction(rig, cmdbuf, cmd_len, NULL, NULL);
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), "%02dM" CR, ch);
+        retval = ar3030_transaction(rig, cmdbuf, strlen(cmdbuf), NULL, NULL);
     }
 
     if (retval == RIG_OK)
@@ -726,11 +724,11 @@ int ar3030_get_channel(RIG *rig, vfo_t vfo, channel_t *chan, int read_only)
 {
     struct ar3030_priv_data *priv = (struct ar3030_priv_data *)rig->state.priv;
     char cmdbuf[BUFSZ], infobuf[BUFSZ];
-    int info_len, cmd_len, retval;
+    int info_len, retval;
 
 
-    cmd_len = sprintf(cmdbuf, "%02dM" CR, chan->channel_num);
-    retval = ar3030_transaction(rig, cmdbuf, cmd_len, infobuf, &info_len);
+    SNPRINTF(cmdbuf, sizeof(cmdbuf), "%02dM" CR, chan->channel_num);
+    retval = ar3030_transaction(rig, cmdbuf, strlen(cmdbuf), infobuf, &info_len);
 
     if (retval != RIG_OK)
     {
@@ -824,16 +822,16 @@ int ar3030_vfo_op(RIG *rig, vfo_t vfo, vfo_op_t op)
 {
     struct ar3030_priv_data *priv = (struct ar3030_priv_data *)rig->state.priv;
     char buf[16];
-    int len, retval;
+    int retval;
 
     switch (op)
     {
     case RIG_OP_MCL:
-        len = sprintf(buf, "%02d%%" CR, priv->curr_ch);
+        SNPRINTF(buf, sizeof(buf), "%02d%%" CR, priv->curr_ch);
         break;
 
     case RIG_OP_FROM_VFO:
-        len = sprintf(buf, "%02dW" CR, priv->curr_ch);
+        SNPRINTF(buf, sizeof(buf), "%02dW" CR, priv->curr_ch);
         priv->curr_vfo = RIG_VFO_MEM;
         break;
 
@@ -841,7 +839,7 @@ int ar3030_vfo_op(RIG *rig, vfo_t vfo, vfo_op_t op)
         return -RIG_EINVAL;
     }
 
-    retval = ar3030_transaction(rig, buf, len, NULL, NULL);
+    retval = ar3030_transaction(rig, buf, strlen(buf), NULL, NULL);
 
     return retval;
 }
