@@ -24,10 +24,6 @@
 
 #include "hamlib/rig.h"
 
-#ifdef HAVE_SYS_TIME_H
-#include <sys/time.h>
-#endif
-
 #define EOM "\r"
 #define TRUE 1
 #define FALSE 0
