@@ -36,7 +36,7 @@
 #define TOK_EL_ROT_MAGICCOMBO    TOKEN_BACKEND(5)
 #define TOK_EL_ROT_MAGICEXTFUNC  TOKEN_BACKEND(6)
 
-extern const struct rot_caps dummy_rot_caps;
-extern const struct rot_caps netrotctl_caps;
+extern struct rot_caps dummy_rot_caps;
+extern struct rot_caps netrotctl_caps;
 
 #endif /* _ROT_DUMMY_H */
