@@ -174,7 +174,10 @@ const struct rig_caps ic706_caps =
     .has_set_level =  RIG_LEVEL_NONE,
     .has_get_parm =  RIG_PARM_NONE,
     .has_set_parm =  RIG_PARM_NONE, /* FIXME: parms */
-    .level_gran =  {},      /* granularity */
+    .level_gran =
+    {
+#include "level_gran_icom.h"
+    },
     .parm_gran =  {},
     .ctcss_list =  NULL,
     .dcs_list =  NULL,
@@ -319,7 +322,10 @@ const struct rig_caps ic706mkii_caps =
     .has_set_level =  RIG_LEVEL_NONE,
     .has_get_parm =  RIG_PARM_NONE,
     .has_set_parm =  RIG_PARM_NONE, /* FIXME: parms */
-    .level_gran =  {},      /* granularity */
+    .level_gran =
+    {
+#include "level_gran_icom.h"
+    },
     .parm_gran =  {},
     .ctcss_list =  NULL,
     .dcs_list =  NULL,
@@ -487,9 +493,9 @@ const struct rig_caps ic706mkiig_caps =
     .has_set_level =  RIG_LEVEL_SET(IC706IIG_LEVEL_ALL),
     .has_get_parm =  RIG_PARM_NONE,
     .has_set_parm =  RIG_PARM_NONE, /* FIXME: parms */
-    .level_gran = {
-        // cppcheck-suppress *
-        [LVL_RAWSTR] = { .min = { .i = 0 }, .max = { .i = 255 } },
+    .level_gran =
+    {
+#include "level_gran_icom.h"
     },
     .parm_gran =  {},
     .ctcss_list =  common_ctcss_list,
