@@ -176,7 +176,9 @@ const struct rig_caps ic7800_caps =
     .has_set_level =  RIG_LEVEL_SET(IC7800_LEVELS),
     .has_get_parm =  IC7800_PARMS,
     .has_set_parm =  RIG_PARM_SET(IC7800_PARMS),    /* FIXME: parms */
-    .level_gran = {
+    .level_gran =
+    {
+#include "level_gran_icom.h"
         // cppcheck-suppress *
         [LVL_RAWSTR] = { .min = { .i = 0 }, .max = { .i = 255 } },
         [LVL_VOXDELAY] = { .min = { .i = 0 }, .max = { .i = 20 }, .step = { .i = 1 } },
