@@ -97,7 +97,9 @@ const struct rig_caps id1_caps =
     .has_set_level =  RIG_LEVEL_SET(ID1_LEVEL_ALL),
     .has_get_parm =  ID1_PARM_ALL,
     .has_set_parm =  ID1_PARM_ALL,
-    .level_gran = {
+    .level_gran =
+    {
+#include "level_gran_icom.h"
         // cppcheck-suppress *
         [LVL_RAWSTR] = { .min = { .i = 0 }, .max = { .i = 255 } },
     },
@@ -143,13 +145,13 @@ const struct rig_caps id1_caps =
 
     .tuning_steps =     {
         {ID1_MODES, kHz(5)},
+        {ID1_MODES, kHz(6.25)},
         {ID1_MODES, kHz(10)},
-        {ID1_MODES, 12500},
+        {ID1_MODES, kHz(12.5)},
         {ID1_MODES, kHz(20)},
         {ID1_MODES, kHz(25)},
         {ID1_MODES, kHz(25)},
         {ID1_MODES, kHz(100)},
-        {ID1_MODES, kHz(6.25)},
         RIG_TS_END,
     },
     /* mode/filter list, remember: order matters! */
