@@ -20,9 +20,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include <hamlib/config.h>
 
 #include <stdlib.h>
 #include <string.h>
@@ -297,7 +295,7 @@ const struct rig_caps pihpsdr_caps =
     .get_powerstat =  kenwood_get_powerstat,
     .get_info =  kenwood_get_info,
     .reset =  kenwood_reset,
-
+    .hamlib_check_rig_caps = HAMLIB_CHECK_RIG_CAPS
 };
 
 /*
@@ -360,7 +358,7 @@ int pihspdr_get_channel(RIG *rig, vfo_t vfo, channel_t *chan, int read_only)
     }
 
     /* put channel num in the command string */
-    sprintf(cmd, "MR0%03d;", chan->channel_num);
+    SNPRINTF(cmd, sizeof(cmd), "MR0%03d;", chan->channel_num);
 
     err = kenwood_transaction(rig, cmd, buf, sizeof(buf));
 
@@ -734,22 +732,22 @@ int pihspdr_set_channel(RIG *rig, vfo_t vfo, const channel_t *chan)
     }
 
     /* P-number       2-3    4 5 6 7   8   9  101112  13 141516  */
-    sprintf(buf, "MW0%03d%011u%c%c%c%02d%02d%03d%c%c%09d0%c%c%s;",
-            chan->channel_num,
-            (unsigned) chan->freq,      /*  4 - frequency */
-            '0' + mode,                 /*  5 - mode */
-            (chan->flags & RIG_CHFLAG_SKIP) ? '1' : '0',    /*  6 - lockout status */
-            sqltype,                    /*  7 - squelch and tone type */
-            tone + 1,                   /*  8 - tone code */
-            code + 1,                   /*  9 - CTCSS code */
-            dcscode,                    /* 10 - DCS code */
-            (chan->funcs & RIG_FUNC_REV) ? '1' : '0', /* 11 - Reverse status */
-            shift,                      /* 12 - shift type */
-            (int) chan->rptr_offs,              /* 13 - offset frequency */
-            tstep + '0',                        /* 14 - Step size */
-            chan->scan_group + '0',         /* 15 - Memory group no */
-            chan->channel_desc              /* 16 - description */
-           );
+    SNPRINTF(buf, sizeof(buf), "MW0%03d%011u%c%c%c%02d%02d%03d%c%c%09d0%c%c%s;",
+             chan->channel_num,
+             (unsigned) chan->freq,      /*  4 - frequency */
+             '0' + mode,                 /*  5 - mode */
+             (chan->flags & RIG_CHFLAG_SKIP) ? '1' : '0',    /*  6 - lockout status */
+             sqltype,                    /*  7 - squelch and tone type */
+             tone + 1,                   /*  8 - tone code */
+             code + 1,                   /*  9 - CTCSS code */
+             dcscode,                    /* 10 - DCS code */
+             (chan->funcs & RIG_FUNC_REV) ? '1' : '0', /* 11 - Reverse status */
+             shift,                      /* 12 - shift type */
+             (int) chan->rptr_offs,              /* 13 - offset frequency */
+             tstep + '0',                        /* 14 - Step size */
+             chan->scan_group + '0',         /* 15 - Memory group no */
+             chan->channel_desc              /* 16 - description */
+            );
     rig_debug(RIG_DEBUG_VERBOSE, "The command will be: %s\n", buf);
 
     err = kenwood_transaction(rig, buf, NULL, 0);
@@ -761,7 +759,7 @@ int pihspdr_set_channel(RIG *rig, vfo_t vfo, const channel_t *chan)
 
     if (chan->split == RIG_SPLIT_ON)
     {
-        snprintf(buf, sizeof(buf), "MW1%03d%011u%c%c%c%02d%02d%03d%c%c%09d0%c%c%s;\n",
+        SNPRINTF(buf, sizeof(buf), "MW1%03d%011u%c%c%c%02d%02d%03d%c%c%09d0%c%c%s;\n",
                  chan->channel_num,
                  (unsigned) chan->tx_freq,       /*  4 - frequency */
                  '0' + tx_mode,                  /*  5 - mode */
@@ -806,20 +804,20 @@ int pihpsdr_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
     case RIG_LEVEL_RFPOWER:
         /* level is float between 0.0 and 1.0, maps to 0 ... 100 */
         kenwood_val = val.f * 100;
-        sprintf(levelbuf, "PC%03d", kenwood_val);
+        SNPRINTF(levelbuf, sizeof(levelbuf), "PC%03d", kenwood_val);
         break;
 
     case RIG_LEVEL_AF:
-        sprintf(levelbuf, "AG%03d", kenwood_val);
+        SNPRINTF(levelbuf, sizeof(levelbuf), "AG%03d", kenwood_val);
         break;
 
     case RIG_LEVEL_RF:
         /* XXX check level range */
-        sprintf(levelbuf, "RG%03d", kenwood_val);
+        SNPRINTF(levelbuf, sizeof(levelbuf), "RG%03d", kenwood_val);
         break;
 
     case RIG_LEVEL_SQL:
-        sprintf(levelbuf, "SQ%03d", kenwood_val);
+        SNPRINTF(levelbuf, sizeof(levelbuf), "SQ%03d", kenwood_val);
         break;
 
     case RIG_LEVEL_AGC:
@@ -829,7 +827,7 @@ int pihpsdr_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
         else if (kenwood_val == RIG_AGC_MEDIUM) { kenwood_val = 15; }
         else if (kenwood_val == RIG_AGC_SLOW) { kenwood_val = 20; }
 
-        sprintf(levelbuf, "GT%03d", kenwood_val);
+        SNPRINTF(levelbuf, sizeof(levelbuf), "GT%03d", kenwood_val);
         break;
 
     case RIG_LEVEL_ATT:
@@ -837,7 +835,7 @@ int pihpsdr_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
         /* set the attenuator if a correct value is entered */
         if (val.i == 0)
         {
-            sprintf(levelbuf, "RA00");
+            SNPRINTF(levelbuf, sizeof(levelbuf), "RA00");
         }
         else
         {
@@ -847,7 +845,7 @@ int pihpsdr_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
             {
                 if (val.i == rig->state.attenuator[i])
                 {
-                    sprintf(levelbuf, "RA%02d", i + 1);
+                    SNPRINTF(levelbuf, sizeof(levelbuf), "RA%02d", i + 1);
                     foundit = 1;
                     break;
                 }
@@ -866,7 +864,7 @@ int pihpsdr_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
         /* set the preamp if a correct value is entered */
         if (val.i == 0)
         {
-            sprintf(levelbuf, "PA0");
+            SNPRINTF(levelbuf, sizeof(levelbuf), "PA0");
         }
         else
         {
@@ -876,7 +874,7 @@ int pihpsdr_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
             {
                 if (val.i == rig->state.preamp[i])
                 {
-                    sprintf(levelbuf, "PA%01d", i + 1);
+                    SNPRINTF(levelbuf, sizeof(levelbuf), "PA%01d", i + 1);
                     foundit = 1;
                     break;
                 }
@@ -896,7 +894,7 @@ int pihpsdr_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
             return -RIG_EINVAL;
         }
 
-        sprintf(levelbuf, "SH%02d", (val.i));
+        SNPRINTF(levelbuf, sizeof(levelbuf), "SH%02d", (val.i));
         break;
 
     case RIG_LEVEL_SLOPE_LOW:
@@ -905,7 +903,7 @@ int pihpsdr_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
             return -RIG_EINVAL;
         }
 
-        sprintf(levelbuf, "SL%02d", (val.i));
+        SNPRINTF(levelbuf, sizeof(levelbuf), "SL%02d", (val.i));
         break;
 
     case RIG_LEVEL_CWPITCH:
@@ -914,7 +912,7 @@ int pihpsdr_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
             return -RIG_EINVAL;
         }
 
-        sprintf(levelbuf, "PT%02d", (val.i / 50) - 8);
+        SNPRINTF(levelbuf, sizeof(levelbuf), "PT%02d", (val.i / 50) - 8);
         break;
 
     case RIG_LEVEL_KEYSPD:
@@ -923,7 +921,7 @@ int pihpsdr_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
             return -RIG_EINVAL;
         }
 
-        sprintf(levelbuf, "KS%03d", val.i);
+        SNPRINTF(levelbuf, sizeof(levelbuf), "KS%03d", val.i);
         break;
 
     default:
