@@ -1627,7 +1627,7 @@ const struct rig_caps thd72a_caps =
     RIG_MODEL(RIG_MODEL_THD72A),
     .model_name = "TH-D72A",
     .mfg_name =  "Kenwood",
-    .version =  TH_VER ".0",
+    .version =  TH_VER ".1",
     .copyright =  "LGPL",
     .status =  RIG_STATUS_STABLE,
     .rig_type =  RIG_TYPE_HANDHELD | RIG_FLAG_APRS | RIG_FLAG_TNC | RIG_FLAG_DXCLUSTER,
@@ -1642,7 +1642,7 @@ const struct rig_caps thd72a_caps =
     .serial_handshake =  RIG_HANDSHAKE_HARDWARE,
     .write_delay =  0,
     .post_write_delay =  0,
-    .timeout =  300,
+    .timeout =  500,
     .retry =  3,
     .has_get_func =  THD72_FUNC_ALL,
     .has_set_func =  THD72_FUNC_ALL,
@@ -1650,10 +1650,9 @@ const struct rig_caps thd72a_caps =
     .has_set_level =  RIG_LEVEL_SET(THD72_LEVEL_ALL),
     .has_get_parm =  THD72_PARMS,
     .has_set_parm =  THD72_PARMS,    /* FIXME: parms */
-    .level_gran = {
-        [LVL_RAWSTR] = { .min = { .i = 0 }, .max = { .i = 5 } },
-        [LVL_SQL] = { .min = { .i = 0 }, .max = { .i = 5 } },
-        [LVL_RFPOWER] = { .min = { .i = 2 }, .max = { .i = 0 } },
+    .level_gran =
+    {
+#include "level_gran_kenwood.h"
     },
     .parm_gran =  {},
     .ctcss_list =  kenwood42_ctcss_list,
