@@ -19,9 +19,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include <hamlib/config.h>
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -190,7 +188,7 @@ static int ts570_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
         return -RIG_EINVAL;
     }
 
-    sprintf(buf, "MD%c", kmode);
+    SNPRINTF(buf, sizeof(buf), "MD%c", kmode);
     retval = kenwood_transaction(rig, buf, NULL, 0);
 
     if (retval != RIG_OK) { return retval; }
@@ -203,7 +201,7 @@ static int ts570_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
     case RIG_MODE_CWR:
     case RIG_MODE_RTTY:
     case RIG_MODE_RTTYR:
-        sprintf(buf, "FW%04d", (int)width);
+        SNPRINTF(buf, sizeof(buf), "FW%04d", (int)width);
         retval = kenwood_transaction(rig, buf, NULL, 0);
 
         if (retval != RIG_OK) { return retval; }
@@ -214,7 +212,7 @@ static int ts570_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
     case RIG_MODE_LSB:
     case RIG_MODE_FM:
     case RIG_MODE_AM:
-        sprintf(buf, "SL%02d", (int)width / 50);
+        SNPRINTF(buf, sizeof(buf), "SL%02d", (int)width / 50);
         retval = kenwood_transaction(rig, buf, NULL, 0);
 
         if (retval != RIG_OK) { return retval; }
@@ -249,11 +247,11 @@ int ts570_set_func(RIG *rig, vfo_t vfo, setting_t func, int status)
             return -RIG_EINVAL;
         }
 
-        sprintf(fctbuf, "NR%01d", status);
+        SNPRINTF(fctbuf, sizeof(fctbuf), "NR%01d", status);
         return kenwood_transaction(rig, fctbuf, NULL, 0);
 
     case RIG_FUNC_TUNER:
-        sprintf(fctbuf, "AC %c0", (0 == status) ? '0' : '1');
+        SNPRINTF(fctbuf, sizeof(fctbuf), "AC %c0", (0 == status) ? '0' : '1');
         return kenwood_transaction(rig, fctbuf, NULL, 0);
 
     default:
@@ -346,7 +344,7 @@ ts570_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
         /* set the preamplifier if a correct value is entered */
         if (kenwood_val == 0)
         {
-            sprintf(levelbuf, "PA0");
+            SNPRINTF(levelbuf, sizeof(levelbuf), "PA0");
         }
         else
         {
@@ -355,7 +353,7 @@ ts570_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
             for (i = 0; i < HAMLIB_MAXDBLSTSIZ; i++)
                 if (kenwood_val == rig->state.preamp[i])
                 {
-                    sprintf(levelbuf, "PA%01d", i + 1);
+                    SNPRINTF(levelbuf, sizeof(levelbuf), "PA%01d", i + 1);
                     break;  /* found - stop searching */
                 }
                 else
@@ -369,13 +367,13 @@ ts570_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
     case RIG_LEVEL_RFPOWER:
         /* level for TS570D is from 0.. 100W in SSB and CW */
         kenwood_val = val.f * 100;
-        sprintf(levelbuf, "PC%03d", kenwood_val);
+        SNPRINTF(levelbuf, sizeof(levelbuf), "PC%03d", kenwood_val);
         return kenwood_transaction(rig, levelbuf, NULL, 0);
 
     case RIG_LEVEL_MICGAIN:
         /* level is from 0..100 */
         kenwood_val = val.f * 100;
-        sprintf(levelbuf, "MG%03d", kenwood_val);
+        SNPRINTF(levelbuf, sizeof(levelbuf), "MG%03d", kenwood_val);
         return kenwood_transaction(rig, levelbuf, NULL, 0);
 
     default:
@@ -561,7 +559,7 @@ int ts570_get_split_vfo(RIG *rig, vfo_t vfo, split_t *split, vfo_t *tx_vfo)
 int ts570_set_split_vfo(RIG *rig, vfo_t vfo, split_t split, vfo_t txvfo)
 {
     char cmdbuf[16], ackbuf[20];
-    int cmd_len, retval;
+    int retval;
     unsigned char vfo_function;
 
     if (vfo != RIG_VFO_CURR)
@@ -582,12 +580,7 @@ int ts570_set_split_vfo(RIG *rig, vfo_t vfo, split_t split, vfo_t txvfo)
         }
 
         /* set RX VFO */
-        cmd_len = sprintf(cmdbuf, "FR%c%c", vfo_function, cmd_trm(rig));
-
-        if (cmd_len < 0)
-        {
-            return -RIG_ETRUNC;
-        }
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), "FR%c%c", vfo_function, cmd_trm(rig));
 
         retval = kenwood_transaction(rig, cmdbuf, NULL, 0);
 
@@ -629,12 +622,7 @@ int ts570_set_split_vfo(RIG *rig, vfo_t vfo, split_t split, vfo_t txvfo)
         }
 
         /* set TX VFO */
-        cmd_len = sprintf(cmdbuf, "FT%c%c", vfo_function, cmd_trm(rig));
-
-        if (cmd_len < 0)
-        {
-            return -RIG_ETRUNC;
-        }
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), "FT%c%c", vfo_function, cmd_trm(rig));
 
         retval = kenwood_transaction(rig, cmdbuf, NULL, 0);
 
@@ -658,12 +646,7 @@ int ts570_set_split_vfo(RIG *rig, vfo_t vfo, split_t split, vfo_t txvfo)
 
             /* and then set it to both vfo's */
             vfo_function = ackbuf[2];
-            cmd_len = sprintf(cmdbuf, "FT%c%c", vfo_function, cmd_trm(rig));
-
-            if (cmd_len < 0)
-            {
-                return -RIG_ETRUNC;
-            }
+            SNPRINTF(cmdbuf, sizeof(cmdbuf), "FT%c%c", vfo_function, cmd_trm(rig));
 
             retval = kenwood_transaction(rig, cmdbuf, NULL, 0);
 
@@ -691,7 +674,7 @@ int ts570_set_split_vfo(RIG *rig, vfo_t vfo, split_t split, vfo_t txvfo)
 int ts570_set_channel(RIG *rig, vfo_t vfo, const channel_t *chan)
 {
     char cmdbuf[30];
-    int retval, cmd_len;
+    int retval;
     int num, freq, tx_freq, tone;
     char mode, tx_mode, tones;
 
@@ -728,13 +711,8 @@ int ts570_set_channel(RIG *rig, vfo_t vfo, const channel_t *chan)
         tone = 0;
     }
 
-    cmd_len = sprintf(cmdbuf, "MW0 %02d%011d%c0%c%02d ",
-                      num, freq, mode, tones, tone);
-
-    if (cmd_len < 0)
-    {
-        return -RIG_ETRUNC;
-    }
+    SNPRINTF(cmdbuf, sizeof(cmdbuf), "MW0 %02d%011d%c0%c%02d ",
+             num, freq, mode, tones, tone);
 
     retval = kenwood_transaction(rig, cmdbuf, NULL, 0);
 
@@ -743,13 +721,8 @@ int ts570_set_channel(RIG *rig, vfo_t vfo, const channel_t *chan)
         return retval;
     }
 
-    cmd_len = sprintf(cmdbuf, "MW1 %02d%011d%c0%c%02d ",
-                      num, tx_freq, tx_mode, tones, tone);
-
-    if (cmd_len < 0)
-    {
-        return -RIG_ETRUNC;
-    }
+    SNPRINTF(cmdbuf, sizeof(cmdbuf), "MW1 %02d%011d%c0%c%02d ",
+             num, tx_freq, tx_mode, tones, tone);
 
     retval = kenwood_transaction(rig, cmdbuf, NULL, 0);
 
@@ -799,7 +772,7 @@ int ts570_set_rit(RIG *rig, vfo_t vfo, shortfreq_t rit)
 {
     char buf[50];
     unsigned char c;
-    int retval, len, i;
+    int retval, i;
 
     if (rit == 0)
     {
@@ -833,12 +806,7 @@ int ts570_set_rit(RIG *rig, vfo_t vfo, shortfreq_t rit)
         c = 'D';
     }
 
-    len = sprintf(buf, "R%c", c);
-
-    if (len < 0)
-    {
-        return -RIG_ETRUNC;
-    }
+    SNPRINTF(buf, sizeof(buf), "R%c", c);
 
     retval = kenwood_transaction(rig, "RC", NULL, 0);
 
@@ -864,7 +832,7 @@ int ts570_set_xit(RIG *rig, vfo_t vfo, shortfreq_t rit)
 {
     char buf[50];
     unsigned char c;
-    int retval, len, i;
+    int retval, i;
 
     if (rit == 0)
     {
@@ -898,12 +866,7 @@ int ts570_set_xit(RIG *rig, vfo_t vfo, shortfreq_t rit)
         c = 'D';
     }
 
-    len = sprintf(buf, "R%c", c);
-
-    if (len < 0)
-    {
-        return -RIG_ETRUNC;
-    }
+    SNPRINTF(buf, sizeof(buf), "R%c", c);
 
     retval = kenwood_transaction(rig, "RC", NULL, 0);
 
@@ -940,7 +903,7 @@ const struct rig_caps ts570s_caps =
     RIG_MODEL(RIG_MODEL_TS570S),
     .model_name = "TS-570S",
     .mfg_name =  "Kenwood",
-    .version =  BACKEND_VER ".0",
+    .version =  BACKEND_VER ".2",
     .copyright =  "LGPL",
     .status =  RIG_STATUS_STABLE,
     .rig_type =  RIG_TYPE_TRANSCEIVER,
@@ -955,7 +918,7 @@ const struct rig_caps ts570s_caps =
     .serial_handshake =  RIG_HANDSHAKE_NONE,
     .write_delay =  0,
     .post_write_delay =  30,
-    .timeout = 400,
+    .timeout = 500,
     .retry =  10,
 
     .has_get_func =  TS570_FUNC_ALL,
@@ -964,7 +927,10 @@ const struct rig_caps ts570s_caps =
     .has_set_level =  RIG_LEVEL_SET(TS570_LEVEL_ALL),
     .has_get_parm =  RIG_PARM_NONE,
     .has_set_parm =  RIG_PARM_NONE,    /* FIXME: parms */
-    .level_gran =  {},                 /* FIXME: granularity */
+    .level_gran =
+    {
+#include "level_gran_kenwood.h"
+    },
     .parm_gran =  {},
     .ctcss_list =  kenwood38_ctcss_list,
     .dcs_list =  NULL,
@@ -977,6 +943,8 @@ const struct rig_caps ts570s_caps =
     .scan_ops =  TS570_SCAN_OPS,
     .targetable_vfo =  RIG_TARGETABLE_FREQ,
     .transceive =  RIG_TRN_RIG,
+    .agc_level_count = 2,
+    .agc_levels = { RIG_AGC_FAST, RIG_AGC_SLOW },
     .bank_qty =   0,
     .chan_desc_sz =  0,
 
@@ -1106,7 +1074,7 @@ const struct rig_caps ts570s_caps =
     .get_powerstat =  kenwood_get_powerstat,
     .scan =  kenwood_scan,
     .reset =  kenwood_reset,
-
+    .hamlib_check_rig_caps = HAMLIB_CHECK_RIG_CAPS
 };
 
 /*
@@ -1122,7 +1090,7 @@ const struct rig_caps ts570d_caps =
     RIG_MODEL(RIG_MODEL_TS570D),
     .model_name = "TS-570D",
     .mfg_name =  "Kenwood",
-    .version =  BACKEND_VER ".0",
+    .version =  BACKEND_VER ".1",
     .copyright =  "LGPL",
     .status =  RIG_STATUS_STABLE,
     .rig_type =  RIG_TYPE_TRANSCEIVER,
@@ -1137,7 +1105,7 @@ const struct rig_caps ts570d_caps =
     .serial_handshake =  RIG_HANDSHAKE_NONE,
     .write_delay =  0,
     .post_write_delay =  30,
-    .timeout = 400,
+    .timeout = 500,
     .retry =  10,
 
     .has_get_func =  TS570_FUNC_ALL,
@@ -1146,7 +1114,10 @@ const struct rig_caps ts570d_caps =
     .has_set_level =  RIG_LEVEL_SET(TS570_LEVEL_ALL),
     .has_get_parm =  RIG_PARM_NONE,
     .has_set_parm =  RIG_PARM_NONE,    /* FIXME: parms */
-    .level_gran =  {},                 /* FIXME: granularity */
+    .level_gran =
+    {
+#include "level_gran_kenwood.h"
+    },
     .parm_gran =  {},
     .ctcss_list =  kenwood38_ctcss_list,
     .dcs_list =  NULL,
@@ -1293,7 +1264,7 @@ const struct rig_caps ts570d_caps =
     .get_powerstat =  kenwood_get_powerstat,
     .scan =  kenwood_scan,
     .reset =  kenwood_reset,
-
+    .hamlib_check_rig_caps = HAMLIB_CHECK_RIG_CAPS
 };
 
 
