@@ -18,15 +18,11 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include <hamlib/config.h>
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>  /* String function definitions */
-#include <unistd.h>  /* UNIX standard function definitions */
-#include <math.h>
 
 #include "hamlib/rig.h"
 #include "serial.h"
@@ -81,7 +77,6 @@ static int ra37xx_one_transaction(RIG *rig, const char *cmd, char *data,
     struct rig_state *rs = &rig->state;
     char cmdbuf[BUFSZ];
     char respbuf[BUFSZ];
-    int cmd_len;
     int retval;
     int pkt_header_len;
     struct timeval tv;
@@ -96,17 +91,17 @@ static int ra37xx_one_transaction(RIG *rig, const char *cmd, char *data,
     if (priv->receiver_id != -1)
     {
         pkt_header_len = 2;
-        cmd_len = sprintf(cmdbuf, SOM "%d%s" EOM, priv->receiver_id, cmd);
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), SOM "%d%s" EOM, priv->receiver_id, cmd);
     }
     else
     {
         pkt_header_len = 1;
-        cmd_len = sprintf(cmdbuf, SOM "%s" EOM, cmd);
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), SOM "%s" EOM, cmd);
     }
 
     rig_flush(&rs->rigport);
 
-    retval = write_block(&rs->rigport, cmdbuf, cmd_len);
+    retval = write_block(&rs->rigport, (unsigned char *) cmdbuf, strlen(cmdbuf));
 
     if (retval != RIG_OK)
     {
@@ -122,7 +117,8 @@ static int ra37xx_one_transaction(RIG *rig, const char *cmd, char *data,
 
     do
     {
-        retval = read_string(&rs->rigport, respbuf, BUFSZ, EOM, strlen(EOM));
+        retval = read_string(&rs->rigport, (unsigned char *) respbuf, BUFSZ, EOM,
+                             strlen(EOM), 0, 1);
 
         if (retval < 0)
         {
@@ -143,8 +139,7 @@ static int ra37xx_one_transaction(RIG *rig, const char *cmd, char *data,
         }
 
         /* drop other receiver id, and "pause" (empty) packets */
-        if ((priv->receiver_id != -1 && (respbuf[1] - '0') != priv->receiver_id) ||
-                retval == pkt_header_len + 1)
+        if ((priv->receiver_id != -1 && (respbuf[1] - '0') != priv->receiver_id))
         {
             if (!rig_check_cache_timeout(&tv, rs->rigport.timeout))
             {
@@ -224,7 +219,7 @@ int ra37xx_init(RIG *rig)
         return -RIG_EINVAL;
     }
 
-    rig->state.priv = (struct ra37xx_priv_data *)malloc(sizeof(
+    rig->state.priv = (struct ra37xx_priv_data *)calloc(1, sizeof(
                           struct ra37xx_priv_data));
 
     if (!rig->state.priv)
@@ -259,12 +254,10 @@ int ra37xx_cleanup(RIG *rig)
     return RIG_OK;
 }
 
-
-
 /*
  * Assumes rig!=NULL, rig->state.priv!=NULL
  */
-int ra37xx_set_conf(RIG *rig, token_t token, const char *val)
+int ra37xx_set_conf2(RIG *rig, token_t token, const char *val, int val_len)
 {
     struct ra37xx_priv_data *priv = (struct ra37xx_priv_data *)rig->state.priv;
     int receiver_id;
@@ -289,19 +282,24 @@ int ra37xx_set_conf(RIG *rig, token_t token, const char *val)
     return RIG_OK;
 }
 
+int ra37xx_set_conf(RIG *rig, token_t token, const char *val)
+{
+    return ra37xx_set_conf2(rig, token, val, 128);
+}
+
 /*
  * assumes rig!=NULL,
  * Assumes rig!=NULL, rig->state.priv!=NULL
  *  and val points to a buffer big enough to hold the conf value.
  */
-int ra37xx_get_conf(RIG *rig, token_t token, char *val)
+int ra37xx_get_conf2(RIG *rig, token_t token, char *val, int val_len)
 {
     struct ra37xx_priv_data *priv = (struct ra37xx_priv_data *)rig->state.priv;
 
     switch (token)
     {
     case TOK_RIGID:
-        sprintf(val, "%d", priv->receiver_id);
+        SNPRINTF(val, val_len, "%d", priv->receiver_id);
         break;
 
     default:
@@ -311,6 +309,11 @@ int ra37xx_get_conf(RIG *rig, token_t token, char *val)
     return RIG_OK;
 }
 
+int ra37xx_get_conf(RIG *rig, token_t token, char *val)
+{
+    return ra37xx_get_conf2(rig, token, val, 128);
+}
+
 /*
  * ra37xx_open
  * Assumes rig!=NULL
@@ -340,14 +343,8 @@ int ra37xx_close(RIG *rig)
 int ra37xx_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 {
     char freqbuf[BUFSZ];
-    int freq_len;
 
-    freq_len = sprintf(freqbuf, "F%lu", (unsigned long)freq);
-
-    if (freq_len < 0)
-    {
-        return -RIG_ETRUNC;
-    }
+    SNPRINTF(freqbuf, sizeof(freqbuf), "F%lu", (unsigned long)freq);
 
     return ra37xx_transaction(rig, freqbuf, NULL, NULL);
 }
@@ -418,9 +415,9 @@ int ra37xx_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 #endif
 
 #ifdef XXREMOVEDXX
-    sprintf(buf, "M%d;B%d,%d", ra_mode, widthtype, widthnum);
+    SNPRINTF(buf, sizeof(buf), "M%d;B%d,%d", ra_mode, widthtype, widthnum);
 #else
-    sprintf(buf, "M%d", ra_mode);
+    SNPRINTF(buf, sizeof(buf), "M%d", ra_mode);
 #endif
 
     return ra37xx_transaction(rig, buf, NULL, NULL);
@@ -474,7 +471,7 @@ int ra37xx_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 
     /* FIXME */
     widthnum = 0;
-    sprintf(buf, "QBCON%d,%d", widthtype, widthnum);
+    SNPRINTF(buf, sizeof(buf), "QBCON%d,%d", widthtype, widthnum);
     retval = ra37xx_transaction(rig, buf, resbuf, &len);
 
     if (retval != RIG_OK)
@@ -495,7 +492,7 @@ int ra37xx_set_func(RIG *rig, vfo_t vfo, setting_t func, int status)
     switch (func)
     {
     case RIG_FUNC_MUTE:
-        sprintf(cmdbuf, "MUTE%d", status ? 1 : 0);
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), "MUTE%d", status ? 1 : 0);
         break;
 
     default:
@@ -547,23 +544,23 @@ int ra37xx_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
     switch (level)
     {
     case RIG_LEVEL_AF:
-        sprintf(cmdbuf, "AFL%d", (int)(val.f * 255));
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), "AFL%d", (int)(val.f * 255));
         break;
 
     case RIG_LEVEL_PREAMP:
-        sprintf(cmdbuf, "RFAMP%d", val.i ? 1 : 0);
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), "RFAMP%d", val.i ? 1 : 0);
         break;
 
     case RIG_LEVEL_CWPITCH: /* BFO */
-        sprintf(cmdbuf, "BFO%d", val.i);
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), "BFO%d", val.i);
         break;
 
     case RIG_LEVEL_SQL:
-        sprintf(cmdbuf, "CORL%d", (int)(val.f * 255));
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), "CORL%d", (int)(val.f * 255));
         break;
 
     case RIG_LEVEL_RF:
-        sprintf(cmdbuf, "G%d", (int)(val.f * 255));
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), "G%d", (int)(val.f * 255));
         break;
 
     case RIG_LEVEL_AGC:
@@ -580,7 +577,8 @@ int ra37xx_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
         default: return -RIG_EINVAL;
         }
 
-        sprintf(cmdbuf, "AGC%d,%d", val.i == RIG_AGC_USER ? 1 : 0, agc);
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), "AGC%d,%d", val.i == RIG_AGC_USER ? 1 : 0,
+                 agc);
         break;
 
     default:
@@ -749,7 +747,7 @@ int ra37xx_set_ant(RIG *rig, vfo_t vfo, ant_t ant, value_t option)
         return -RIG_EINVAL;
     }
 
-    sprintf(buf, "ANT%d", i_ant);
+    SNPRINTF(buf, sizeof(buf), "ANT%d", i_ant);
 
     return ra37xx_transaction(rig, buf, NULL, NULL);
 }
@@ -788,7 +786,7 @@ int ra37xx_set_mem(RIG *rig, vfo_t vfo, int ch)
 
     /* NB: does a RIG_OP_TO_VFO!*/
 
-    sprintf(buf, "CHAN%d", ch);
+    SNPRINTF(buf, sizeof(buf), "CHAN%d", ch);
 
     return ra37xx_transaction(rig, buf, NULL, NULL);
 }
@@ -828,7 +826,7 @@ int ra37xx_scan(RIG *rig, vfo_t vfo, scan_t scan, int ch)
         return -RIG_EINVAL;
     }
 
-    sprintf(buf, "SCAN%d,0", scantype);
+    SNPRINTF(buf, sizeof(buf), "SCAN%d,0", scantype);
 
     return ra37xx_transaction(rig, buf, NULL, NULL);
 }
@@ -848,7 +846,7 @@ int ra37xx_vfo_op(RIG *rig, vfo_t vfo, vfo_op_t op)
             return ret;
         }
 
-        sprintf(buf, "STRE%d", ch);
+        SNPRINTF(buf, sizeof(buf), "STRE%d", ch);
         return ra37xx_transaction(rig, buf, NULL, NULL);
 
     case RIG_OP_TO_VFO:
@@ -859,7 +857,7 @@ int ra37xx_vfo_op(RIG *rig, vfo_t vfo, vfo_op_t op)
             return ret;
         }
 
-        sprintf(buf, "CHAN%d", ch);
+        SNPRINTF(buf, sizeof(buf), "CHAN%d", ch);
         return ra37xx_transaction(rig, buf, NULL, NULL);
 
     default:
