@@ -65,17 +65,13 @@
  * This backend supports the Ten-Tec Orion (565) and Orion II (566) transceivers.
  * \n This backend tested mostly with firmware versions 1.372 and 2.062a
  */
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include <hamlib/config.h>
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <ctype.h>
 #include <string.h>  /* String function definitions */
-#include <unistd.h>  /* UNIX standard function definitions */
-#include <time.h>
-#include <sys/time.h>
+#include <math.h>
 
 #include <hamlib/rig.h>
 #include "bandplan.h"
@@ -131,7 +127,7 @@ static int tt565_transaction(RIG *rig, const char *cmd, int cmd_len, char *data,
         int retval;
         rs = &rig->state;
         rig_flush(&rs->rigport); /* discard pending i/p */
-        retval = write_block(&rs->rigport, cmd, cmd_len);
+        retval = write_block(&rs->rigport, (unsigned char *) cmd, cmd_len);
 
         if (retval != RIG_OK)
         {
@@ -155,7 +151,7 @@ static int tt565_transaction(RIG *rig, const char *cmd, int cmd_len, char *data,
         ft1 = tt565_timenow();
 #endif
         *data_len = data_len_init;  /* restore orig. buffer length */
-        *data_len = read_string(&rs->rigport, data, *data_len,
+        *data_len = read_string(&rs->rigport, (unsigned char *) data, *data_len,
                                 EOM, strlen(EOM), 0, 1);
 
         if (!strncmp(data, "Z!", 2))     // command unrecognized??
@@ -196,7 +192,7 @@ static int tt565_transaction(RIG *rig, const char *cmd, int cmd_len, char *data,
                           "** retry after delay (io=%d, retry=%d) **\n",
                           passcount, itry);
                 *data_len = data_len_init;  /* restore orig. buffer length */
-                read_string(&rs->rigport, data, *data_len,
+                read_string(&rs->rigport, (unsigned char *) data, *data_len,
                             EOM, strlen(EOM), 0, 1);      // purge the input stream...
                 continue;                   // now go retry the full command
             }
@@ -229,7 +225,7 @@ static int tt565_transaction(RIG *rig, const char *cmd, int cmd_len, char *data,
 int tt565_init(RIG *rig)
 {
     struct tt565_priv_data *priv;
-    rig->state.priv = (struct tt565_priv_data *)malloc(sizeof(
+    rig->state.priv = (struct tt565_priv_data *)calloc(1, sizeof(
                           struct tt565_priv_data));
 
     if (!rig->state.priv) { return -RIG_ENOMEM; } /* no memory available */
@@ -367,7 +363,7 @@ static char which_vfo(const RIG *rig, vfo_t vfo)
 
 int tt565_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 {
-    int cmd_len, retval, i, in_range;
+    int retval, i, in_range;
     freq_range_t this_range;
     char cmdbuf[TT565_BUFSIZE];
     /* Check for valid frequency request.
@@ -402,9 +398,9 @@ int tt565_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 #ifdef TT565_ASCII_FREQ
     /*  Use ASCII mode to set frequencies */
     // cppcheck-suppress *
-    cmd_len = sprintf(cmdbuf, "*%cF%"PRIll EOM,
-                      which_vfo(rig, vfo),
-                      (int64_t)freq);
+    SNPRINTF(cmdbuf, sizeof(cmdbuf), "*%cF%"PRIll EOM,
+             which_vfo(rig, vfo),
+             (int64_t)freq);
 #else
     /* Use binary mode */
     /* Set frequency using Orion's binary mode (short) sequence.
@@ -414,7 +410,6 @@ int tt565_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
     /* Construct command packet by brute force. */
     unsigned int myfreq;
     myfreq = freq;
-    cmd_len = 7;
     cmdbuf[0] = '*';
     cmdbuf[1] = which_vfo(rig, vfo);
     cmdbuf[2] = (myfreq & 0xff000000) >> 24;
@@ -422,8 +417,9 @@ int tt565_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
     cmdbuf[4] = (myfreq & 0x0000ff00) >> 8;
     cmdbuf[5] =  myfreq & 0x000000ff;
     cmdbuf[6] = '\r';   /* i.e. EOM */
+    cmdbuf[7] = 0;
 #endif
-    retval = tt565_transaction(rig, cmdbuf, cmd_len, NULL, NULL);
+    retval = tt565_transaction(rig, cmdbuf, strlen(cmdbuf), NULL, NULL);
 
     return retval;
 }
@@ -438,20 +434,20 @@ int tt565_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
  */
 int tt565_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 {
-    int cmd_len, resp_len, retval;
+    int resp_len, retval;
     char cmdbuf[TT565_BUFSIZE], respbuf[TT565_BUFSIZE];
     unsigned int binf;
 #ifdef TT565_ASCII_FREQ
     /*  use ASCII mode */
-    cmd_len = sprintf(cmdbuf, "?%cF" EOM,
-                      which_vfo(rig, vfo));
+    SNPRINTF(cmdbuf, sizeof(cmdbuf), "?%cF" EOM,
+             which_vfo(rig, vfo));
 #else
     /* Get freq with Orion binary mode short sequence. */
-    cmd_len = sprintf(cmdbuf, "?%c" EOM,
-                      which_vfo(rig, vfo));
+    SNPRINTF(cmdbuf, sizeof(cmdbuf), "?%c" EOM,
+             which_vfo(rig, vfo));
 #endif
     resp_len = sizeof(respbuf);
-    retval = tt565_transaction(rig, cmdbuf, cmd_len, respbuf, &resp_len);
+    retval = tt565_transaction(rig, cmdbuf, strlen(cmdbuf), respbuf, &resp_len);
 
     if (retval != RIG_OK)
     {
@@ -501,10 +497,10 @@ int tt565_set_vfo(RIG *rig, vfo_t vfo)
     {
         char vfobuf[TT565_BUFSIZE];
         /* Select Sub or Main RX */
-        int vfo_len = sprintf(vfobuf, "*K%c" EOM,
-                              vfo == RIG_VFO_SUB ? 'S' : 'M');
+        SNPRINTF(vfobuf, sizeof(vfobuf), "*K%c" EOM,
+                 vfo == RIG_VFO_SUB ? 'S' : 'M');
 
-        return tt565_transaction(rig, vfobuf, vfo_len, NULL, NULL);
+        return tt565_transaction(rig, vfobuf, strlen(vfobuf), NULL, NULL);
     }
 
     priv->vfo_curr = vfo;
@@ -539,15 +535,15 @@ int tt565_get_vfo(RIG *rig, vfo_t *vfo)
  */
 int tt565_set_split_vfo(RIG *rig, vfo_t vfo, split_t split, vfo_t tx_vfo)
 {
-    int cmd_len, retval;
+    int retval;
     char cmdbuf[TT565_BUFSIZE];
 
-    cmd_len = sprintf(cmdbuf, "*KV%c%c%c" EOM,
-                      which_vfo(rig, vfo),
-                      'N',           /* FIXME */
-                      which_vfo(rig, RIG_SPLIT_ON == split ? tx_vfo : vfo));
+    SNPRINTF(cmdbuf, sizeof(cmdbuf), "*KV%c%c%c" EOM,
+             which_vfo(rig, vfo),
+             'N',           /* FIXME */
+             which_vfo(rig, RIG_SPLIT_ON == split ? tx_vfo : vfo));
 
-    retval = tt565_transaction(rig, cmdbuf, cmd_len, NULL, NULL);
+    retval = tt565_transaction(rig, cmdbuf, strlen(cmdbuf), NULL, NULL);
 
     return retval;
 }
@@ -580,13 +576,13 @@ static vfo_t tt2vfo(char c)
  */
 int tt565_get_split_vfo(RIG *rig, vfo_t vfo, split_t *split, vfo_t *tx_vfo)
 {
-    int cmd_len, resp_len, retval;
+    int resp_len, retval;
     char cmdbuf[TT565_BUFSIZE], respbuf[TT565_BUFSIZE];
     char ttreceiver;
 
-    cmd_len = sprintf(cmdbuf, "?KV" EOM);
+    SNPRINTF(cmdbuf, sizeof(cmdbuf), "?KV" EOM);
     resp_len = sizeof(respbuf);
-    retval = tt565_transaction(rig, cmdbuf, cmd_len, respbuf, &resp_len);
+    retval = tt565_transaction(rig, cmdbuf, strlen(cmdbuf), respbuf, &resp_len);
 
     if (retval != RIG_OK)
     {
@@ -628,7 +624,7 @@ int tt565_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 {
     struct rig_state *rs = &rig->state;
     char ttmode, ttreceiver;
-    int mdbuf_len, retval;
+    int retval;
     char mdbuf[TT565_BUFSIZE];
 
     switch (mode)
@@ -660,14 +656,29 @@ int tt565_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 
     ttreceiver = which_receiver(rig, vfo);
 
-    mdbuf_len = sprintf(mdbuf, "*R%cM%c" EOM "*R%cF%d" EOM,
-                        ttreceiver,
-                        ttmode,
-                        ttreceiver,
-                        (int)width
-                       );
 
-    retval = write_block(&rs->rigport, mdbuf, mdbuf_len);
+    if (rig->caps->rig_model == RIG_MODEL_TT599)
+    {
+        // Additional R%CF0 puts bandwidth control back to bandwidth knob
+        SNPRINTF(mdbuf, sizeof(mdbuf), "*R%cM%c" EOM "*R%cF%d" EOM "R%cF0" EOM,
+                 ttreceiver,
+                 ttmode,
+                 ttreceiver,
+                 (int)width,
+                 ttreceiver
+                );
+    }
+    else
+    {
+        SNPRINTF(mdbuf, sizeof(mdbuf), "*R%cM%c" EOM "*R%cF%d" EOM,
+                 ttreceiver,
+                 ttmode,
+                 ttreceiver,
+                 (int)width
+                );
+    }
+
+    retval = write_block(&rs->rigport, (unsigned char *) mdbuf, strlen(mdbuf));
 
     return retval;
 }
@@ -684,16 +695,16 @@ int tt565_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
  */
 int tt565_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 {
-    int cmd_len, resp_len, retval;
+    int resp_len, retval;
     char cmdbuf[TT565_BUFSIZE], respbuf[TT565_BUFSIZE];
     char ttmode, ttreceiver;
 
     ttreceiver = which_receiver(rig, vfo);
 
     /* Query mode */
-    cmd_len = sprintf(cmdbuf, "?R%cM" EOM, ttreceiver);
+    SNPRINTF(cmdbuf, sizeof(cmdbuf), "?R%cM" EOM, ttreceiver);
     resp_len = sizeof(respbuf);
-    retval = tt565_transaction(rig, cmdbuf, cmd_len, respbuf, &resp_len);
+    retval = tt565_transaction(rig, cmdbuf, strlen(cmdbuf), respbuf, &resp_len);
 
     if (retval != RIG_OK)
     {
@@ -734,9 +745,9 @@ int tt565_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
     /* Orion may need some time to "recover" from ?RxM before ?RxF */
     hl_usleep(80000);      // try 80 ms
     /* Query passband width (filter) */
-    cmd_len = sprintf(cmdbuf, "?R%cF" EOM, ttreceiver);
+    SNPRINTF(cmdbuf, sizeof(cmdbuf), "?R%cF" EOM, ttreceiver);
     resp_len = sizeof(respbuf);
-    retval = tt565_transaction(rig, cmdbuf, cmd_len, respbuf, &resp_len);
+    retval = tt565_transaction(rig, cmdbuf, strlen(cmdbuf), respbuf, &resp_len);
 
     if (retval != RIG_OK)
     {
@@ -764,14 +775,14 @@ int tt565_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
  */
 int tt565_set_ts(RIG *rig, vfo_t vfo, shortfreq_t ts)
 {
-    int cmd_len, retval;
+    int retval;
     char cmdbuf[TT565_BUFSIZE];
 
-    cmd_len = sprintf(cmdbuf, "*R%cI%d" EOM,
-                      which_receiver(rig, vfo),
-                      (int)ts);
+    SNPRINTF(cmdbuf, sizeof(cmdbuf), "*R%cI%d" EOM,
+             which_receiver(rig, vfo),
+             (int)ts);
 
-    retval = tt565_transaction(rig, cmdbuf, cmd_len, NULL, NULL);
+    retval = tt565_transaction(rig, cmdbuf, strlen(cmdbuf), NULL, NULL);
 
     return retval;
 }
@@ -785,14 +796,14 @@ int tt565_set_ts(RIG *rig, vfo_t vfo, shortfreq_t ts)
  */
 int tt565_get_ts(RIG *rig, vfo_t vfo, shortfreq_t *ts)
 {
-    int cmd_len, resp_len, retval;
+    int resp_len, retval;
     char cmdbuf[TT565_BUFSIZE], respbuf[TT565_BUFSIZE];
 
-    cmd_len = sprintf(cmdbuf, "?R%cI" EOM,
-                      which_receiver(rig, vfo));
+    SNPRINTF(cmdbuf, sizeof(cmdbuf), "?R%cI" EOM,
+             which_receiver(rig, vfo));
 
     resp_len = sizeof(respbuf);
-    retval = tt565_transaction(rig, cmdbuf, cmd_len, respbuf, &resp_len);
+    retval = tt565_transaction(rig, cmdbuf, strlen(cmdbuf), respbuf, &resp_len);
 
     if (retval != RIG_OK)
     {
@@ -821,14 +832,14 @@ int tt565_get_ts(RIG *rig, vfo_t vfo, shortfreq_t *ts)
  */
 int tt565_set_rit(RIG *rig, vfo_t vfo, shortfreq_t rit)
 {
-    int cmd_len, retval;
+    int retval;
     char cmdbuf[TT565_BUFSIZE];
 
-    cmd_len = sprintf(cmdbuf, "*R%cR%d" EOM,
-                      which_receiver(rig, vfo),
-                      (int)rit);
+    SNPRINTF(cmdbuf, sizeof(cmdbuf), "*R%cR%d" EOM,
+             which_receiver(rig, vfo),
+             (int)rit);
 
-    retval = tt565_transaction(rig, cmdbuf, cmd_len, NULL, NULL);
+    retval = tt565_transaction(rig, cmdbuf, strlen(cmdbuf), NULL, NULL);
 
     return retval;
 }
@@ -842,14 +853,14 @@ int tt565_set_rit(RIG *rig, vfo_t vfo, shortfreq_t rit)
  */
 int tt565_get_rit(RIG *rig, vfo_t vfo, shortfreq_t *rit)
 {
-    int cmd_len, resp_len, retval;
+    int resp_len, retval;
     char cmdbuf[TT565_BUFSIZE], respbuf[TT565_BUFSIZE];
 
-    cmd_len = sprintf(cmdbuf, "?R%cR" EOM,
-                      which_receiver(rig, vfo));
+    SNPRINTF(cmdbuf, sizeof(cmdbuf), "?R%cR" EOM,
+             which_receiver(rig, vfo));
 
     resp_len = sizeof(respbuf);
-    retval = tt565_transaction(rig, cmdbuf, cmd_len, respbuf, &resp_len);
+    retval = tt565_transaction(rig, cmdbuf, strlen(cmdbuf), respbuf, &resp_len);
 
     if (retval != RIG_OK)
     {
@@ -878,16 +889,16 @@ int tt565_get_rit(RIG *rig, vfo_t vfo, shortfreq_t *rit)
  */
 int tt565_set_xit(RIG *rig, vfo_t vfo, shortfreq_t xit)
 {
-    int cmd_len, retval;
+    int retval;
     char cmdbuf[TT565_BUFSIZE];
 
     /* Sub receiver does not contain an XIT setting */
 
-    cmd_len = sprintf(cmdbuf, "*R%cX%d" EOM,
-                      'M',
-                      (int)xit);
+    SNPRINTF(cmdbuf, sizeof(cmdbuf), "*R%cX%d" EOM,
+             'M',
+             (int)xit);
 
-    retval = tt565_transaction(rig, cmdbuf, cmd_len, NULL, NULL);
+    retval = tt565_transaction(rig, cmdbuf, strlen(cmdbuf), NULL, NULL);
 
     return retval;
 }
@@ -901,14 +912,14 @@ int tt565_set_xit(RIG *rig, vfo_t vfo, shortfreq_t xit)
  */
 int tt565_get_xit(RIG *rig, vfo_t vfo, shortfreq_t *xit)
 {
-    int cmd_len, resp_len, retval;
+    int resp_len, retval;
     char cmdbuf[TT565_BUFSIZE], respbuf[TT565_BUFSIZE];
 
-    cmd_len = sprintf(cmdbuf, "?R%cX" EOM,
-                      'M');
+    SNPRINTF(cmdbuf, sizeof(cmdbuf), "?R%cX" EOM,
+             'M');
 
     resp_len = sizeof(respbuf);
-    retval = tt565_transaction(rig, cmdbuf, cmd_len, respbuf, &resp_len);
+    retval = tt565_transaction(rig, cmdbuf, strlen(cmdbuf), respbuf, &resp_len);
 
     if (retval != RIG_OK)
     {
@@ -939,7 +950,7 @@ int tt565_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
     struct rig_state *rs = &rig->state;
 
     return write_block(&rs->rigport,
-                       ptt == RIG_PTT_ON ? "*TK" EOM : "*TU" EOM, 4);
+                       (unsigned char *)(ptt == RIG_PTT_ON ? "*TK" EOM : "*TU" EOM), 4);
 }
 
 /**
@@ -1071,14 +1082,14 @@ const char *tt565_get_info(RIG *rig)
  */
 int tt565_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
 {
-    int retval, cmd_len = 0, ii;
+    int retval, ii;
     char cmdbuf[TT565_BUFSIZE], cc;
 
     switch (level)
     {
     case RIG_LEVEL_RFPOWER:
-        cmd_len = sprintf(cmdbuf, "*TP%d" EOM,
-                          (int)(val.f * 100));
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), "*TP%d" EOM,
+                 (int)(val.f * 100));
         break;
 
     case RIG_LEVEL_AGC:
@@ -1097,30 +1108,30 @@ int tt565_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
         default: cc = 'M';
         }
 
-        cmd_len = sprintf(cmdbuf, "*R%cA%c" EOM,
-                          which_receiver(rig, vfo),
-                          cc);
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), "*R%cA%c" EOM,
+                 which_receiver(rig, vfo),
+                 cc);
         break;
 
     case RIG_LEVEL_AF:
         /* AF Gain, float 0.0 - 1.0 */
-        cmd_len = sprintf(cmdbuf, "*U%c%d" EOM,
-                          which_receiver(rig, vfo),
-                          (int)(val.f * 255));
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), "*U%c%d" EOM,
+                 which_receiver(rig, vfo),
+                 (int)(val.f * 255));
         break;
 
     case RIG_LEVEL_IF:
         /* This is passband tuning int Hz */
-        cmd_len = sprintf(cmdbuf, "*R%cP%d" EOM,
-                          which_receiver(rig, vfo),
-                          val.i);
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), "*R%cP%d" EOM,
+                 which_receiver(rig, vfo),
+                 val.i);
         break;
 
     case RIG_LEVEL_RF:
         /* This is IF Gain, float 0.0 - 1.0 */
-        cmd_len = sprintf(cmdbuf, "*R%cG%d" EOM,
-                          which_receiver(rig, vfo),
-                          (int)(val.f * 100));
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), "*R%cG%d" EOM,
+                 which_receiver(rig, vfo),
+                 (int)(val.f * 100));
         break;
 
     case RIG_LEVEL_ATT:
@@ -1132,9 +1143,9 @@ int tt565_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
             if (rig->caps->attenuator[ii] > val.i) { break; }
         }
 
-        cmd_len = sprintf(cmdbuf, "*R%cT%d" EOM,
-                          which_receiver(rig, vfo),
-                          ii);
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), "*R%cT%d" EOM,
+                 which_receiver(rig, vfo),
+                 ii);
         break;
 
     case RIG_LEVEL_PREAMP:
@@ -1146,27 +1157,27 @@ int tt565_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
         }
 
         /* RF Preamp (main Rx), int 0 or 1 */
-        cmd_len = sprintf(cmdbuf, "*RME%d" EOM,
-                          val.i == 0 ? 0 : 1);
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), "*RME%d" EOM,
+                 val.i == 0 ? 0 : 1);
         break;
 
     case RIG_LEVEL_SQL:
         /* Squelch level, float 0.0 - 1.0 */
-        cmd_len = sprintf(cmdbuf, "*R%cS%d" EOM,
-                          which_receiver(rig, vfo),
-                          (int)((val.f * 127) - 127));
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), "*R%cS%d" EOM,
+                 which_receiver(rig, vfo),
+                 (int)((val.f * 127) - 127));
         break;
 
     case RIG_LEVEL_MICGAIN:
         /* Mic gain, float 0.0 - 1.0 */
-        cmd_len = sprintf(cmdbuf, "*TM%d" EOM,
-                          (int)(val.f * 100));
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), "*TM%d" EOM,
+                 (int)(val.f * 100));
         break;
 
     case RIG_LEVEL_COMP:
         /* Speech Processor, float 0.0 - 1.0 */
-        cmd_len = sprintf(cmdbuf, "*TS%d" EOM,
-                          (int)(val.f * 9));
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), "*TS%d" EOM,
+                 (int)(val.f * 9));
         break;
 
     case RIG_LEVEL_CWPITCH:
@@ -1178,8 +1189,8 @@ int tt565_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
         if (val.i > TT565_TONE_MAX) { val.i = TT565_TONE_MAX; }
         else if (val.i < TT565_TONE_MIN) { val.i = TT565_TONE_MIN; }
 
-        cmd_len = sprintf(cmdbuf, "*CT%d" EOM,
-                          val.i);
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), "*CT%d" EOM,
+                 val.i);
         break;
 
     case RIG_LEVEL_KEYSPD:
@@ -1191,34 +1202,46 @@ int tt565_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
         if (val.i > TT565_CW_MAX) { val.i = TT565_CW_MAX; }
         else if (val.i < TT565_CW_MIN) { val.i = TT565_CW_MIN; }
 
-        cmd_len = sprintf(cmdbuf, "*CS%d" EOM,
-                          val.i);
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), "*CS%d" EOM,
+                 val.i);
         break;
 
     case RIG_LEVEL_NR:
-        /* Noise Reduction (blanking) Float 0.0 - 1.0
-            For some reason NB setting is supported in 1.372, but
-           NR, NOTCH, and AN are not.
-           FOR NOW -- RIG_LEVEL_NR controls the Orion NB setting
-        */
-        cmd_len = sprintf(cmdbuf, "*R%cNB%d" EOM,
-                          which_receiver(rig, vfo),
-                          (int)(val.f * 9));
+        if (rig->caps->rig_model == RIG_MODEL_TT599)
+        {
+            ii = (int)(val.f * 10);
+
+            if (ii > 9) { ii = 9; } // cannot set NR level 10 apparently
+
+            SNPRINTF(cmdbuf, sizeof(cmdbuf), "*RMNN%c" EOM, ii);
+        }
+        else
+        {
+            /* Noise Reduction (blanking) Float 0.0 - 1.0
+                For some reason NB setting is supported in 1.372, but
+               NR, NOTCH, and AN are not.
+               FOR NOW -- RIG_LEVEL_NR controls the Orion NB setting
+            */
+            SNPRINTF(cmdbuf, sizeof(cmdbuf), "*R%cNB%d" EOM,
+                     which_receiver(rig, vfo),
+                     (int)(val.f * 9));
+        }
+
         break;
 
     case RIG_LEVEL_VOXDELAY:
         /* VOX delay, float tenths of seconds */
-        cmd_len = sprintf(cmdbuf, "*TH%4.2f" EOM, 0.1 * val.f);
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), "*TH%4.2f" EOM, 0.1 * val.f);
         break;
 
     case RIG_LEVEL_VOXGAIN:
         /* Float, 0.0 - 1.0 */
-        cmd_len = sprintf(cmdbuf, "*TG%d" EOM, (int)(100.0 * val.f));
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), "*TG%d" EOM, (int)(100.0 * val.f));
         break;
 
     case RIG_LEVEL_ANTIVOX:
         /* Float, 0.0 - 1.0 */
-        cmd_len = sprintf(cmdbuf, "*TA%d" EOM, (int)(100.0 * val.f));
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), "*TA%d" EOM, (int)(100.0 * val.f));
         break;
 
     default:
@@ -1227,7 +1250,7 @@ int tt565_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
         return -RIG_EINVAL;
     }
 
-    retval = tt565_transaction(rig, cmdbuf, cmd_len, NULL, NULL);
+    retval = tt565_transaction(rig, cmdbuf, strlen(cmdbuf), NULL, NULL);
     return retval;
 }
 
@@ -1265,7 +1288,7 @@ int tt565_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
  */
 int tt565_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 {
-    int retval, cmd_len, lvl_len;
+    int retval, lvl_len;
     char cmdbuf[TT565_BUFSIZE], lvlbuf[TT565_BUFSIZE];
 
     /* Optimize: sort the switch cases with the most frequent first */
@@ -1280,29 +1303,75 @@ int tt565_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
             return retval;
         }
 
-        /* in Xmit, response is @STFuuuRvvvSwww (or ...Swwww)
-            uuu = 000-100 (apx) fwd watts
-                        vvv = 000-100       rev watts
-                        www = 256-999  256 * VSWR
-           in Rcv,  response is @SRMuuuSvvv
-            uuu = 000-100 (apx) Main S meter
-                        vvv = 000-100 (apx) Sub  S meter
-        */
-
-        if (lvlbuf[1] != 'S' || lvl_len < 5)
+        if (rig->caps->rig_model == RIG_MODEL_TT599)
         {
-            rig_debug(RIG_DEBUG_ERR, "%s: unexpected answer '%s'\n",
-                      __func__, lvlbuf);
-            return -RIG_EPROTO;
-        }
+            double fwd, ref;
 
-        if (lvlbuf[2] == 'T')
+            /* in Xmit, response is @STF99R10<cr> 99 watts forward,1.0 watt reflected
+                uu = fwd watts
+                vv = rev watts x 10
+
+               in Rcv,  response is @SRM16<CR> Indicates 16 dbm
+                uuu = 000-100 (apx) Main S meter
+            */
+
+            if (lvlbuf[1] != 'S' || lvl_len < 5)
+            {
+                rig_debug(RIG_DEBUG_ERR, "%s: unexpected answer '%s'\n",
+                          __func__, lvlbuf);
+                return -RIG_EPROTO;
+            }
+
+            if (lvlbuf[2] == 'T')
+            {
+                ref = atof(strchr(lvlbuf + 2, 'R') + 1) / 10.0;   /* reflected power */
+                fwd = atof(strchr(lvlbuf + 2, 'F') + 1);          /* forward power */
+
+                if (fwd == 0.0)
+                {
+                    val->f = 0.0;                                 /* no forward power */
+                }
+                else if (fwd == ref)                              /* too high SWR */
+                {
+                    val->f = 9.99;
+                }
+                else
+                {
+                    val->f = (1 + sqrt(ref / fwd)) / (1 - sqrt(ref / fwd)); /* calculate SWR */
+                }
+
+                if (val->f < 1.0) { val->f = 9.99; }              /* high VSWR */
+            }
+            else { val->f = 0.0; }  /* SWR in Receive = 0.0 */
+
+        }
+        else
         {
-            val->f = atof(strchr(lvlbuf + 5, 'S') + 1) / 256.0;
 
-            if (val->f < 1.0) { val->f = 9.99; }    /* high VSWR */
+            /* in Xmit, response is @STFuuuRvvvSwww (or ...Swwww)
+                uuu = 000-100 (apx) fwd watts
+                            vvv = 000-100       rev watts
+                            www = 256-999  256 * VSWR
+               in Rcv,  response is @SRMuuuSvvv
+                uuu = 000-100 (apx) Main S meter
+                            vvv = 000-100 (apx) Sub  S meter
+            */
+
+            if (lvlbuf[1] != 'S' || lvl_len < 5)
+            {
+                rig_debug(RIG_DEBUG_ERR, "%s: unexpected answer '%s'\n",
+                          __func__, lvlbuf);
+                return -RIG_EPROTO;
+            }
+
+            if (lvlbuf[2] == 'T')
+            {
+                val->f = atof(strchr(lvlbuf + 5, 'S') + 1) / 256.0;
+
+                if (val->f < 1.0) { val->f = 9.99; }    /* high VSWR */
+            }
+            else { val->f = 0.0; }  /* SWR in Receive = 0.0 */
         }
-        else { val->f = 0.0; }  /* SWR in Receive = 0.0 */
 
         break;
 
@@ -1368,11 +1437,11 @@ int tt565_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
         break;
 
     case RIG_LEVEL_AGC:
-        cmd_len = sprintf(cmdbuf, "?R%cA" EOM,
-                          which_receiver(rig, vfo));
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), "?R%cA" EOM,
+                 which_receiver(rig, vfo));
 
         lvl_len = sizeof(lvlbuf);
-        retval = tt565_transaction(rig, cmdbuf, cmd_len, lvlbuf, &lvl_len);
+        retval = tt565_transaction(rig, cmdbuf, strlen(cmdbuf), lvlbuf, &lvl_len);
 
         if (retval != RIG_OK)
         {
@@ -1405,11 +1474,11 @@ int tt565_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
         break;
 
     case RIG_LEVEL_AF:
-        cmd_len = sprintf(cmdbuf, "?U%c" EOM,
-                          which_receiver(rig, vfo));
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), "?U%c" EOM,
+                 which_receiver(rig, vfo));
 
         lvl_len = sizeof(lvlbuf);
-        retval = tt565_transaction(rig, cmdbuf, cmd_len, lvlbuf, &lvl_len);
+        retval = tt565_transaction(rig, cmdbuf, strlen(cmdbuf), lvlbuf, &lvl_len);
 
         if (retval != RIG_OK)
         {
@@ -1427,11 +1496,11 @@ int tt565_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
         break;
 
     case RIG_LEVEL_IF:
-        cmd_len = sprintf(cmdbuf, "?R%cP" EOM,  /* passband tuning */
-                          which_receiver(rig, vfo));
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), "?R%cP" EOM,  /* passband tuning */
+                 which_receiver(rig, vfo));
 
         lvl_len = sizeof(lvlbuf);
-        retval = tt565_transaction(rig, cmdbuf, cmd_len, lvlbuf, &lvl_len);
+        retval = tt565_transaction(rig, cmdbuf, strlen(cmdbuf), lvlbuf, &lvl_len);
 
         if (retval != RIG_OK)
         {
@@ -1449,11 +1518,11 @@ int tt565_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
         break;
 
     case RIG_LEVEL_RF:
-        cmd_len = sprintf(cmdbuf, "?R%cG" EOM,
-                          which_receiver(rig, vfo));
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), "?R%cG" EOM,
+                 which_receiver(rig, vfo));
 
         lvl_len = sizeof(lvlbuf);
-        retval = tt565_transaction(rig, cmdbuf, cmd_len, lvlbuf, &lvl_len);
+        retval = tt565_transaction(rig, cmdbuf, strlen(cmdbuf), lvlbuf, &lvl_len);
 
         if (retval != RIG_OK)
         {
@@ -1471,11 +1540,11 @@ int tt565_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
         break;
 
     case RIG_LEVEL_ATT:
-        cmd_len = sprintf(cmdbuf, "?R%cT" EOM,
-                          which_receiver(rig, vfo));
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), "?R%cT" EOM,
+                 which_receiver(rig, vfo));
 
         lvl_len = sizeof(lvlbuf);
-        retval = tt565_transaction(rig, cmdbuf, cmd_len, lvlbuf, &lvl_len);
+        retval = tt565_transaction(rig, cmdbuf, strlen(cmdbuf), lvlbuf, &lvl_len);
 
         if (retval != RIG_OK)
         {
@@ -1528,11 +1597,11 @@ int tt565_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
         break;
 
     case RIG_LEVEL_SQL:
-        cmd_len = sprintf(cmdbuf, "?R%cS" EOM,
-                          which_receiver(rig, vfo));
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), "?R%cS" EOM,
+                 which_receiver(rig, vfo));
 
         lvl_len = sizeof(lvlbuf);
-        retval = tt565_transaction(rig, cmdbuf, cmd_len, lvlbuf, &lvl_len);
+        retval = tt565_transaction(rig, cmdbuf, strlen(cmdbuf), lvlbuf, &lvl_len);
 
         if (retval != RIG_OK)
         {
@@ -1626,27 +1695,35 @@ int tt565_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
         break;
 
     case RIG_LEVEL_NR:
+
         /* RIG_LEVEL_NR controls Orion NB setting - TEMP */
-        cmd_len = sprintf(cmdbuf, "?R%cNB" EOM,
-                          which_receiver(rig, vfo));
+        if (rig->caps->rig_model == RIG_MODEL_TT599)
+        {
+            SNPRINTF(cmdbuf, sizeof(cmdbuf), "?RMNN" EOM)
+        }
+        else
+        {
+            SNPRINTF(cmdbuf, sizeof(cmdbuf), "?R%cNB" EOM,
+                     which_receiver(rig, vfo));
+        }
 
         lvl_len = sizeof(lvlbuf);
-        retval = tt565_transaction(rig, cmdbuf, cmd_len, lvlbuf, &lvl_len);
+        retval = tt565_transaction(rig, cmdbuf, strlen(cmdbuf), lvlbuf, &lvl_len);
 
         if (retval != RIG_OK)
         {
             return retval;
         }
 
-        if (lvlbuf[1] != 'R' || lvlbuf[3] != 'N' || lvlbuf[4] != 'B' ||
-                lvl_len < 6)
+        if (lvlbuf[1] != 'R' || lvl_len < 6)
         {
             rig_debug(RIG_DEBUG_ERR, "%s: unexpected answer '%s'\n",
                       __func__, lvlbuf);
             return -RIG_EPROTO;
         }
 
-        val->f = atof(lvlbuf + 5) / 9.0; /* Note 0-9 -> 0.0 - 1.0 */
+        sscanf(lvlbuf + 5, "%f", &val->f);
+        val->f /= 10.0;
         break;
 
     case RIG_LEVEL_VOXDELAY: /* =VOXDELAY, tenths of secs. */
@@ -1766,28 +1843,26 @@ int tt565_vfo_op(RIG *rig, vfo_t vfo, vfo_op_t op)
     struct tt565_priv_data *priv = (struct tt565_priv_data *)rig->state.priv;
     char cmdbuf[TT565_BUFSIZE];
     int retval;
-    int cmd_len;
 
     switch (op)
     {
     case RIG_OP_TO_VFO:
     case RIG_OP_FROM_VFO:
-        cmd_len = sprintf(cmdbuf, "*K%c%c%d" EOM,
-                          op == RIG_OP_TO_VFO ? 'R' : 'W',
-                          which_vfo(rig, vfo),
-                          priv->ch);
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), "*K%c%c%d" EOM,
+                 op == RIG_OP_TO_VFO ? 'R' : 'W',
+                 which_vfo(rig, vfo),
+                 priv->ch);
         break;
 
     case RIG_OP_TUNE:
         strcpy(cmdbuf, "*TTT" EOM);
-        cmd_len = 5;
         break;
 
     case RIG_OP_UP:
     case RIG_OP_DOWN:
-        cmd_len = sprintf(cmdbuf, "*%cS%c1" EOM,
-                          which_vfo(rig, vfo),
-                          op == RIG_OP_UP ? '+' : '-');
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), "*%cS%c1" EOM,
+                 which_vfo(rig, vfo),
+                 op == RIG_OP_UP ? '+' : '-');
         break;
 
     default:
@@ -1796,7 +1871,7 @@ int tt565_vfo_op(RIG *rig, vfo_t vfo, vfo_op_t op)
         return -RIG_EINVAL;
     }
 
-    retval = tt565_transaction(rig, cmdbuf, cmd_len, NULL, NULL);
+    retval = tt565_transaction(rig, cmdbuf, strlen(cmdbuf), NULL, NULL);
     return retval;
 }
 
@@ -1845,8 +1920,8 @@ int tt565_send_morse(RIG *rig, vfo_t vfo, const char *msg)
 
     for (ic = 0; ic < msg_len; ic++)
     {
-        int cmdl = sprintf(morsecmd, "/%c" EOM, msg[ic]);
-        retval = tt565_transaction(rig, morsecmd, cmdl, NULL, NULL);
+        SNPRINTF(morsecmd, sizeof(morsecmd), "/%c" EOM, msg[ic]);
+        retval = tt565_transaction(rig, morsecmd, strlen(morsecmd), NULL, NULL);
 
         if (retval != RIG_OK)
         {
@@ -1876,7 +1951,7 @@ int tt565_send_morse(RIG *rig, vfo_t vfo, const char *msg)
 int tt565_set_func(RIG *rig, vfo_t vfo, setting_t func, int status)
 {
     char fcmdbuf[TT565_BUFSIZE];
-    int retval, fcmdlen;
+    int retval;
 
     if (vfo != RIG_VFO_CURR)
     {
@@ -1886,17 +1961,17 @@ int tt565_set_func(RIG *rig, vfo_t vfo, setting_t func, int status)
     switch (func)
     {
     case RIG_FUNC_TUNER:
-        fcmdlen = sprintf(fcmdbuf, "*TT%c" EOM, !status ? 0 : 1);
+        SNPRINTF(fcmdbuf, sizeof(fcmdbuf), "*TT%c" EOM, !status ? 0 : 1);
         break;
 
     case RIG_FUNC_VOX:
-        fcmdlen = sprintf(fcmdbuf, "*TV%c" EOM, !status ? 0 : 1);
+        SNPRINTF(fcmdbuf, sizeof(fcmdbuf), "*TV%c" EOM, !status ? 0 : 1);
         break;
 
     case RIG_FUNC_LOCK:
-        fcmdlen = sprintf(fcmdbuf, "*%c%c" EOM,
-                          which_vfo(rig, vfo),
-                          !status ? 'U' : 'L');
+        SNPRINTF(fcmdbuf, sizeof(fcmdbuf), "*%c%c" EOM,
+                 which_vfo(rig, vfo),
+                 !status ? 'U' : 'L');
         break;
 
     case RIG_FUNC_NB:
@@ -1904,9 +1979,9 @@ int tt565_set_func(RIG *rig, vfo_t vfo, setting_t func, int status)
         RIG_LEVEL_NR which maps to NB setting due to firmware
         limitation.
         */
-        fcmdlen = sprintf(fcmdbuf, "*R%cNB%c" EOM,
-                          which_receiver(rig, vfo),
-                          !status ? '0' : '4');
+        SNPRINTF(fcmdbuf, sizeof(fcmdbuf), "*R%cNB%c" EOM,
+                 which_receiver(rig, vfo),
+                 !status ? '0' : '4');
         break;
 
     default:
@@ -1915,7 +1990,7 @@ int tt565_set_func(RIG *rig, vfo_t vfo, setting_t func, int status)
         return -RIG_EINVAL;
     }
 
-    retval = tt565_transaction(rig, fcmdbuf, fcmdlen, NULL, NULL);
+    retval = tt565_transaction(rig, fcmdbuf, strlen(fcmdbuf), NULL, NULL);
 
     if (retval != RIG_OK)
     {
@@ -1937,7 +2012,7 @@ int tt565_set_func(RIG *rig, vfo_t vfo, setting_t func, int status)
 int tt565_get_func(RIG *rig, vfo_t vfo, setting_t func, int *status)
 {
     char fcmdbuf[TT565_BUFSIZE], frespbuf[TT565_BUFSIZE];
-    int retval, fcmdlen, fresplen;
+    int retval, fresplen;
 
     if (vfo != RIG_VFO_CURR)
     {
@@ -1947,19 +2022,19 @@ int tt565_get_func(RIG *rig, vfo_t vfo, setting_t func, int *status)
     switch (func)
     {
     case RIG_FUNC_TUNER:
-        fcmdlen = sprintf(fcmdbuf, "?TT" EOM);
+        SNPRINTF(fcmdbuf, sizeof(fcmdbuf), "?TT" EOM);
         break;
 
     case RIG_FUNC_VOX:
-        fcmdlen = sprintf(fcmdbuf, "?TV" EOM);
+        SNPRINTF(fcmdbuf, sizeof(fcmdbuf), "?TV" EOM);
         break;
 
     case RIG_FUNC_LOCK:
-        fcmdlen = sprintf(fcmdbuf, "?%cU" EOM,
-                          which_vfo(rig, vfo));
+        SNPRINTF(fcmdbuf, sizeof(fcmdbuf), "?%cU" EOM,
+                 which_vfo(rig, vfo));
         /* needs special treatment */
         fresplen = sizeof(frespbuf);
-        retval = tt565_transaction(rig, fcmdbuf, fcmdlen,
+        retval = tt565_transaction(rig, fcmdbuf, strlen(fcmdbuf),
                                    frespbuf, &fresplen);
 
         if (retval != RIG_OK)
@@ -1975,11 +2050,11 @@ int tt565_get_func(RIG *rig, vfo_t vfo, setting_t func, int *status)
         /* Note NB should be a LEVEL for Orion. It is also
            available through LEVEL_NR
         */
-        fcmdlen = sprintf(fcmdbuf, "?R%cNB" EOM,
-                          which_receiver(rig, vfo));
+        SNPRINTF(fcmdbuf, sizeof(fcmdbuf), "?R%cNB" EOM,
+                 which_receiver(rig, vfo));
         /* needs special treatment */
         fresplen = sizeof(frespbuf);
-        retval = tt565_transaction(rig, fcmdbuf, fcmdlen,
+        retval = tt565_transaction(rig, fcmdbuf, strlen(fcmdbuf),
                                    frespbuf, &fresplen);
 
         if (retval != RIG_OK)
@@ -1998,7 +2073,7 @@ int tt565_get_func(RIG *rig, vfo_t vfo, setting_t func, int *status)
     }
 
     fresplen = sizeof(frespbuf);
-    retval = tt565_transaction(rig, fcmdbuf, fcmdlen, frespbuf, &fresplen);
+    retval = tt565_transaction(rig, fcmdbuf, strlen(fcmdbuf), frespbuf, &fresplen);
 
     if (retval != RIG_OK)
     {
