@@ -18,10 +18,7 @@
  *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
-
-#include <stdlib.h>
 #include <string.h>  /* String function definitions */
-#include <unistd.h>  /* UNIX standard function definitions */
 #include <math.h>
 #include <errno.h>
 
@@ -36,7 +33,6 @@
 
 #ifdef V4L_IOCTL
 
-#include <stdlib.h>
 #include "idx_builtin.h"
 
 
@@ -76,7 +72,7 @@ const struct rig_caps v4l_caps =
     .mfg_name =  "Video4Linux",
     .version =  "20120107.0",
     .copyright =  "LGPL",
-    .status =  RIG_STATUS_BETA,
+    .status =  RIG_STATUS_STABLE,
     .rig_type =  RIG_TYPE_PCRECEIVER,
     .ptt_type =  RIG_PTT_NONE,
     .dcd_type =  RIG_DCD_NONE,
@@ -143,7 +139,7 @@ const struct rig_caps v4l_caps =
     .get_level =  v4l_get_level,
 
     .get_info =  v4l_get_info,
-
+    .hamlib_check_rig_caps = HAMLIB_CHECK_RIG_CAPS
 };
 
 /*
