@@ -319,7 +319,10 @@ const struct rig_caps ft817_caps =
     .has_set_level =       RIG_LEVEL_BAND_SELECT,
     .has_get_parm =        RIG_PARM_NONE,
     .has_set_parm =        RIG_PARM_NONE,
-    .level_gran =          {},                     /* granularity */
+    .level_gran =
+    {
+#include "level_gran_yaesu.h"
+    },
     .parm_gran =           {},
     .ctcss_list =          common_ctcss_list,
     .dcs_list =            common_dcs_list,   /* only 104 out of 106 supported */
@@ -466,7 +469,10 @@ const struct rig_caps ft818_caps =
     .has_set_level =       RIG_LEVEL_BAND_SELECT,
     .has_get_parm =        RIG_PARM_NONE,
     .has_set_parm =        RIG_PARM_NONE,
-    .level_gran =          {},                     /* granularity */
+    .level_gran =
+    {
+#include "level_gran_yaesu.h"
+    },
     .parm_gran =           {},
     .ctcss_list =          common_ctcss_list,
     .dcs_list =            common_dcs_list,   /* only 104 out of 106 supported */
