@@ -37,8 +37,8 @@
 #include "bandplan.h"
 #include "serial.h"
 #include "newcat.h"
+#include "yaesu.h"
 #include "ft891.h"
-#include "idx_builtin.h"
 
 /* Prototypes */
 static int ft891_init(RIG *rig);
@@ -156,7 +156,9 @@ const struct rig_caps ft891_caps =
     .has_set_level =      RIG_LEVEL_SET(FT891_LEVELS),
     .has_get_parm =       RIG_PARM_NONE,
     .has_set_parm =       RIG_PARM_NONE,
-    .level_gran = {
+    .level_gran =
+    {
+#include "level_gran_yaesu.h"
         // cppcheck-suppress *
         [LVL_RAWSTR] = { .min = { .i = 0 }, .max = { .i = 255 } },
         [LVL_CWPITCH] = { .min = { .i = 300 }, .max = { .i = 1050 }, .step = { .i = 50 } },
