@@ -84,13 +84,10 @@
 */
 
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include <hamlib/config.h>
 
 #include <stdlib.h>
 #include <string.h>  /* String function definitions */
-#include <unistd.h>  /* UNIX standard function definitions */
 #include <sys/time.h> /* for timeofday call */
 
 #include "hamlib/rig.h"
@@ -567,13 +564,13 @@ int ft980_transaction(RIG *rig, const unsigned char *cmd, unsigned char *data,
                       int expected_len)
 {
     int retval;
-    char echo_back[YAESU_CMD_LENGTH];
+    unsigned char echo_back[YAESU_CMD_LENGTH];
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
     rig_flush(&rig->state.rigport);
 
-    retval = write_block(&rig->state.rigport, (const char *)cmd, YAESU_CMD_LENGTH);
+    retval = write_block(&rig->state.rigport, cmd, YAESU_CMD_LENGTH);
 
     if (retval < 0)
     {
@@ -587,7 +584,8 @@ int ft980_transaction(RIG *rig, const unsigned char *cmd, unsigned char *data,
         return retval;
     }
 
-    if (retval != YAESU_CMD_LENGTH || memcmp(echo_back, cmd, YAESU_CMD_LENGTH))
+    if (retval != YAESU_CMD_LENGTH
+            || (memcmp(echo_back, cmd, YAESU_CMD_LENGTH) != 0))
     {
         return -RIG_EPROTO;
     }
@@ -599,7 +597,7 @@ int ft980_transaction(RIG *rig, const unsigned char *cmd, unsigned char *data,
         return retval;
     }
 
-    retval = read_block(&rig->state.rigport, (char *)data, expected_len);
+    retval = read_block(&rig->state.rigport, data, expected_len);
 
     if (retval < 0)
     {
@@ -753,14 +751,14 @@ int ft980_open(RIG *rig)
 
         do
         {
-            write_block(&rig->state.rigport, (char *) cmd_ON_OFF,
+            write_block(&rig->state.rigport, cmd_ON_OFF,
                         YAESU_CMD_LENGTH);
-            retval = read_block(&rig->state.rigport, (char *) echo_back, YAESU_CMD_LENGTH);
+            retval = read_block(&rig->state.rigport, echo_back, YAESU_CMD_LENGTH);
         }
         while (retval != 5 && retry_count2++ < rig->state.rigport.retry);
 
-        write_block(&rig->state.rigport, (char *) cmd_OK, YAESU_CMD_LENGTH);
-        retval = read_block(&rig->state.rigport, (char *) &priv->update_data,
+        write_block(&rig->state.rigport, cmd_OK, YAESU_CMD_LENGTH);
+        retval = read_block(&rig->state.rigport, (unsigned char *) &priv->update_data,
                             FT980_ALL_STATUS_LENGTH);
     }
     while (!priv->update_data.ext_ctl_flag
@@ -799,14 +797,14 @@ int ft980_close(RIG *rig)
 
         do
         {
-            write_block(&rig->state.rigport, (char *) cmd_ON_OFF,
+            write_block(&rig->state.rigport, cmd_ON_OFF,
                         YAESU_CMD_LENGTH);
-            retval = read_block(&rig->state.rigport, (char *) echo_back, YAESU_CMD_LENGTH);
+            retval = read_block(&rig->state.rigport, echo_back, YAESU_CMD_LENGTH);
         }
         while (retval != 5 && retry_count2++ < rig->state.rigport.retry);
 
-        write_block(&rig->state.rigport, (char *) cmd_OK, YAESU_CMD_LENGTH);
-        retval = read_block(&rig->state.rigport, (char *) &priv->update_data,
+        write_block(&rig->state.rigport, cmd_OK, YAESU_CMD_LENGTH);
+        retval = read_block(&rig->state.rigport, (unsigned char *) &priv->update_data,
                             FT980_ALL_STATUS_LENGTH);
     }
     while (priv->update_data.ext_ctl_flag
