@@ -1,2 +1,2 @@
 /* This date time is from the last non-merge commit to Hamlib. */
-#define HAMLIBDATETIME "Jan 10 01:31:41Z 2023 SHA=921cc5"
+#define HAMLIBDATETIME "Apr 05 11:43:08Z 2023 SHA=6eecd3"
