@@ -1360,6 +1360,7 @@ static int read_string_generic(hamlib_port_t *p,
                           direct);
             }
         }
+
         while (++i < 10 && errno == EBUSY);   // 50ms should be enough
 
         /* if we get 0 bytes or an error something is wrong */
@@ -1381,6 +1382,13 @@ static int read_string_generic(hamlib_port_t *p,
 
         total_count += (int) rd_count;
 
+        if (rxbuffer[0] == ';' && total_count > 1)
+        {
+
+        }
+
+        if (total_count == rxmax) { break; }
+
         if (stopset && memchr(stopset, rxbuffer[total_count - 1], stopset_len))
         {
             if (minlen == 1) { minlen = total_count; }
@@ -1395,6 +1403,18 @@ static int read_string_generic(hamlib_port_t *p,
         }
     }
 
+    if (total_count > 1 && rxbuffer[0] == ';')
+    {
+        while (rxbuffer[0] == ';' && rxbuffer[0] != 0 && total_count >  1)
+        {
+            memmove(rxbuffer, &rxbuffer[1], strlen((char *)rxbuffer) - 1);
+            --total_count;
+        }
+
+        rig_debug(RIG_DEBUG_VERBOSE,
+                  "%s: skipping single ';' chars at beginning of reply\n", __func__);
+    }
+
     /*
      * Doesn't hurt anyway. But be aware, some binary protocols may have
      * null chars within the received buffer.
