@@ -25,7 +25,7 @@
 #include <hamlib/rotator.h>
 
 int frontrot_set_conf(ROT *rot, token_t token, const char *val);
-int frontrot_get_conf(ROT *rot, token_t token, char *val);
+int frontrot_get_conf(ROT *rot, token_t token, char *val, int val_len);
 
 
 #endif /* _ROT_CONF_H */
