@@ -154,7 +154,8 @@ int main(int argc, char *argv[])
     char vbuf[1024];
 
     int err = setvbuf(stderr, vbuf, _IOFBF, sizeof(vbuf));
-    if (err) rig_debug(RIG_DEBUG_ERR, "%s: setvbuf err=%s\n", __func__, strerror(err));
+
+    if (err) { rig_debug(RIG_DEBUG_ERR, "%s: setvbuf err=%s\n", __func__, strerror(err)); }
 
     while (1)
     {
