@@ -12,9 +12,7 @@
 
 #include "misc.h"
 
-#ifdef HAVE_CONFIG_H
-#  include "config.h"
-#endif
+#include <hamlib/config.h>
 
 #define SERIAL_PORT "/dev/ttyUSB0"
 
